# competitor
# dict, key, the name
# namedtuple

import my_time
from collections import namedtuple
from operator import attrgetter

Competitor = namedtuple('Competitor',['name','tstart','tfinal','elapsed'])

def create_competitor(dataline):
    values = dataline.split(";")
    name = values[0]
    tstart = my_time.Time(values[1])
    try:
        tfinal = my_time.Time(values[2])
    except:
        print("Warning, tfinal is wrong for {}".format(dataline))
        return None
    elapsed = tfinal - tstart
    return Competitor(name,tstart,tfinal,elapsed)

class CompetitorsList:
    def __init__(self,input_list=None):
        if input_list:
            self.complist = input_list[:]
        else:
            self.complist = []

    def read_scorecard(self,fname):
        with open(fname, mode='rt', encoding='utf-8') as f:
            for dataline in f:
                competitor = create_competitor(dataline)
                if competitor is not None:
                    self.complist.append(competitor)
                    

    def __str__(self):
        format_string = "{:<15} {:<10} {:<10} {:<10}\n"
        message = format_string.format('name','start time','final time','elapsed')
        for c in self.complist:
            message += format_string.format(str(c.name), str(c.tstart), str(c.tfinal), str(c.elapsed))
        return(message)

    def sorted_by(self, sorting_attribute):
        return CompetitorsList(sorted(self.complist, key=attrgetter(sorting_attribute)))
